Assemblies comparison report
Author: Sergey Aganezov
Description: Assembly comparison

# COMPUTATIONAL BIOLOGY LABORATORY

# CAMSA report

### Per assembly overview

id | name | # APs | orientation (O / SO / U) | nc | OC / OSC | IC / ISC | MAP
--- | --- | --- | --- | --- | --- | --- | ---
1 | scaffmatch | 19 | 19 / 0 / 0 | 9 | 10 / 0 | 2 / 0 | 16 (84.21 %)
2 | sga | 42 | 42 / 0 / 0 | 14 | 18 / 0 | 20 / 0 | 25 (59.52 %)
3 | soap2 | 2 | 2 / 0 / 0 | 2 | 0 / 0 | 0 / 0 | 2 (100.00 %)
id | name | # APs | orientation (O / SO / U) | nc | OC / OSC | IC / ISC | MAP

### Individual assemblies

scaffmatch [1]

ctg1 | ctg2 | or1 | or2 | or | ssc | sc | osc | oc | un | map
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
contig_37 | contig_38 | + | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_36 | contig_60 | + | - | O | 0 | 0 | 0 | 1 | 1 | 1
contig_43 | contig_53 | + | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_30 | contig_31 | + | - | O | 0 | 0 | 0 | 1 | 1 | 1
contig_19 | contig_7 | + | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_33 | contig_56 | + | - | O | 0 | 0 | 0 | 1 | 1 | 0
contig_25 | contig_26 | + | - | O | 0 | 0 | 0 | 1 | 1 | 1
contig_16 | contig_17 | + | - | O | 0 | 0 | 0 | 1 | 1 | 0
contig_41 | contig_57 | + | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_49 | contig_54 | + | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_29 | contig_31 | + | + | O | 0 | 0 | 0 | 0 | 1 | 1
contig_62 | contig_63 | + | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_24 | contig_5 | - | - | O | 0 | 1 | 0 | 1 | 1 | 0
contig_0 | contig_48 | + | - | O | 0 | 0 | 0 | 1 | 1 | 1
contig_23 | contig_5 | + | - | O | 0 | 1 | 0 | 1 | 1 | 1
contig_28 | contig_29 | + | + | O | 0 | 0 | 0 | 0 | 1 | 1
contig_44 | contig_53 | + | + | O | 0 | 0 | 0 | 1 | 1 | 1
contig_32 | contig_59 | + | - | O | 0 | 0 | 0 | 1 | 1 | 1
contig_39 | contig_42 | + | - | O | 0 | 0 | 0 | 0 | 1 | 1
ctg1 | ctg2 | or1 | or2 | or | ssc | sc | osc | oc | un | map

sga [2]

ctg1 | ctg2 | or1 | or2 | or | ssc | sc | osc | oc | un | map
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
contig_32 | contig_33 | - | - | O | 0 | 1 | 0 | 1 | 1 | 0
contig_15 | contig_66 | + | + | O | 0 | 0 | 0 | 0 | 1 | 1
contig_33 | contig_34 | + | + | O | 0 | 1 | 0 | 1 | 1 | 1
contig_20 | contig_65 | - | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_12 | contig_27 | - | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_24 | contig_40 | + | - | O | 0 | 1 | 0 | 0 | 1 | 1
contig_42 | contig_58 | - | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_17 | contig_64 | + | + | O | 0 | 0 | 0 | 1 | 1 | 1
contig_54 | contig_64 | - | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_13 | contig_34 | - | - | O | 0 | 1 | 0 | 0 | 1 | 1
contig_23 | contig_4 | + | + | O | 0 | 1 | 0 | 1 | 1 | 0
contig_60 | contig_61 | + | + | O | 0 | 0 | 0 | 1 | 1 | 0
contig_0 | contig_5 | - | - | O | 0 | 1 | 0 | 1 | 1 | 0
contig_1 | contig_56 | + | + | O | 0 | 0 | 0 | 0 | 1 | 1
contig_56 | contig_57 | + | + | O | 0 | 0 | 0 | 1 | 1 | 1
contig_41 | contig_61 | - | - | O | 0 | 1 | 0 | 0 | 1 | 1
contig_26 | contig_3 | - | - | O | 0 | 1 | 0 | 0 | 1 | 1
contig_21 | contig_5 | + | + | O | 0 | 1 | 0 | 0 | 1 | 1
contig_40 | contig_66 | - | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_21 | contig_22 | - | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_20 | contig_27 | + | + | O | 0 | 0 | 0 | 0 | 1 | 1
contig_0 | contig_63 | + | + | O | 0 | 1 | 0 | 1 | 1 | 0
contig_0 | contig_2 | - | - | O | 0 | 1 | 0 | 0 | 1 | 1
contig_0 | contig_48 | + | + | O | 0 | 1 | 0 | 1 | 1 | 0
contig_3 | contig_34 | - | - | O | 0 | 1 | 0 | 0 | 1 | 0
contig_25 | contig_65 | + | + | O | 0 | 0 | 0 | 1 | 1 | 0
contig_16 | contig_17 | + | + | O | 0 | 0 | 0 | 1 | 1 | 1
contig_53 | contig_8 | - | - | O | 0 | 0 | 0 | 1 | 1 | 0
contig_36 | contig_41 | + | + | O | 0 | 1 | 0 | 1 | 1 | 0
contig_25 | contig_26 | - | - | O | 0 | 0 | 0 | 1 | 1 | 0
contig_23 | contig_40 | - | - | O | 0 | 1 | 0 | 0 | 1 | 0
contig_24 | contig_4 | - | + | O | 0 | 1 | 0 | 1 | 1 | 1
contig_12 | contig_22 | + | + | O | 0 | 0 | 0 | 0 | 1 | 1
contig_18 | contig_19 | + | + | O | 0 | 0 | 0 | 0 | 1 | 1
contig_2 | contig_21 | - | - | O | 0 | 1 | 0 | 0 | 1 | 0
contig_14 | contig_62 | + | + | O | 0 | 0 | 0 | 0 | 1 | 1
contig_3 | contig_32 | - | - | O | 0 | 1 | 0 | 1 | 1 | 0
contig_13 | contig_26 | + | + | O | 0 | 1 | 0 | 0 | 1 | 0
contig_30 | contig_58 | + | + | O | 0 | 0 | 0 | 1 | 1 | 0
contig_1 | contig_50 | - | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_18 | contig_4 | - | - | O | 0 | 0 | 0 | 0 | 1 | 1
contig_32 | contig_59 | - | - | O | 0 | 1 | 0 | 1 | 1 | 0
ctg1 | ctg2 | or1 | or2 | or | ssc | sc | osc | oc | un | map

soap2 [3]

ctg1 | ctg2 | or1 | or2 | or | ssc | sc | osc | oc | un | map
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
contig_35 | contig_39 | + | + | O | 0 | 0 | 0 | 0 | 1 | 1
contig_43 | contig_46 | - | - | O | 0 | 0 | 0 | 0 | 1 | 1
ctg1 | ctg2 | or1 | or2 | or | ssc | sc | osc | oc | un | map

### Assemblies comparison

[ scaffmatch; sga; soap2 ]

Advancedfilter options
sources:
ctg1:
ctg2:
or1:
or2:
am:
ssc:
sc:
osc:
oc:
map:

Fragment length filtration is not available, as no data regarding fragments length was provided

Logical `OR` per column filters

sources | ctg1 | ctg2 | oor1 | oor2 | por1 | por2 | or1 | or2 | cw | or | ssc | sc | osc | oc | map | self_id
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
[2] | contig_32 | contig_33 | - | - | None | None | - | - | 1.0 | O | 0 | [2] | 0 | [1] | 0 | m_0
[2] | contig_15 | contig_66 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_1
[2] | contig_33 | contig_34 | + | + | + | + | + | + | 1.0 | O | 0 | [2] | 0 | [1] | 1 | m_2
[2] | contig_20 | contig_65 | - | - | - | - | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_3
[2] | contig_12 | contig_27 | - | - | - | - | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_4
[1] | contig_37 | contig_38 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_5
[1] | contig_36 | contig_60 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | [2] | 1 | m_6
[2] | contig_24 | contig_40 | + | - | + | - | + | - | 1.0 | O | 0 | [2] | 0 | 0 | 1 | m_7
[2] | contig_42 | contig_58 | - | - | - | - | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_8
[2] | contig_17 | contig_64 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | [1] | 1 | m_9
[2] | contig_54 | contig_64 | - | - | - | - | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_10
[2] | contig_13 | contig_34 | - | - | - | - | - | - | 1.0 | O | 0 | [2] | 0 | 0 | 1 | m_11
[1] | contig_43 | contig_53 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_12
[2] | contig_23 | contig_4 | + | + | None | None | + | + | 1.0 | O | 0 | [2] | 0 | [1] | 0 | m_13
[1] | contig_30 | contig_31 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | [2] | 1 | m_14
[3] | contig_35 | contig_39 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_15
[1] | contig_19 | contig_7 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_16
[2] | contig_60 | contig_61 | + | + | None | None | + | + | 1.0 | O | 0 | 0 | 0 | [1] | 0 | m_17
[1] | contig_33 | contig_56 | + | - | None | None | + | - | 1.0 | O | 0 | 0 | 0 | [2] | 0 | m_18
[2] | contig_0 | contig_5 | - | - | None | None | - | - | 1.0 | O | 0 | [2] | 0 | [1] | 0 | m_19
[2] | contig_1 | contig_56 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_20
[1] | contig_25 | contig_26 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | [2] | 1 | m_21
[2] | contig_56 | contig_57 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | [1] | 1 | m_22
[2] | contig_41 | contig_61 | - | - | - | - | - | - | 1.0 | O | 0 | [2] | 0 | 0 | 1 | m_23
[2] | contig_26 | contig_3 | - | - | - | - | - | - | 1.0 | O | 0 | [2] | 0 | 0 | 1 | m_24
[2] | contig_21 | contig_5 | + | + | + | + | + | + | 1.0 | O | 0 | [2] | 0 | 0 | 1 | m_25
[2] | contig_40 | contig_66 | - | - | - | - | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_26
[2] | contig_21 | contig_22 | - | - | - | - | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_27
[2] | contig_20 | contig_27 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_28
[2] | contig_0 | contig_63 | + | + | None | None | + | + | 1.0 | O | 0 | [2] | 0 | [1] | 0 | m_29
[2] | contig_0 | contig_2 | - | - | - | - | - | - | 1.0 | O | 0 | [2] | 0 | 0 | 1 | m_30
[2] | contig_0 | contig_48 | + | + | None | None | + | + | 1.0 | O | 0 | [2] | 0 | [1] | 0 | m_31
[1] | contig_16 | contig_17 | + | - | None | None | + | - | 1.0 | O | 0 | 0 | 0 | [2] | 0 | m_32
[2] | contig_3 | contig_34 | - | - | None | None | - | - | 1.0 | O | 0 | [2] | 0 | 0 | 0 | m_33
[2] | contig_25 | contig_65 | + | + | None | None | + | + | 1.0 | O | 0 | 0 | 0 | [1] | 0 | m_34
[2] | contig_16 | contig_17 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | [1] | 1 | m_35
[2] | contig_53 | contig_8 | - | - | None | None | - | - | 1.0 | O | 0 | 0 | 0 | [1] | 0 | m_36
[2] | contig_36 | contig_41 | + | + | None | None | + | + | 1.0 | O | 0 | [2] | 0 | [1] | 0 | m_37
[2] | contig_25 | contig_26 | - | - | None | None | - | - | 1.0 | O | 0 | 0 | 0 | [1] | 0 | m_38
[2] | contig_23 | contig_40 | - | - | None | None | - | - | 1.0 | O | 0 | [2] | 0 | 0 | 0 | m_39
[2] | contig_24 | contig_4 | - | + | - | + | - | + | 1.0 | O | 0 | [2] | 0 | [1] | 1 | m_40
[2] | contig_12 | contig_22 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_41
[1] | contig_41 | contig_57 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_42
[2] | contig_18 | contig_19 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_43
[2] | contig_2 | contig_21 | - | - | None | None | - | - | 1.0 | O | 0 | [2] | 0 | 0 | 0 | m_44
[2] | contig_14 | contig_62 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_45
[1] | contig_49 | contig_54 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_46
[1] | contig_29 | contig_31 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_47
[1] | contig_62 | contig_63 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_48
[2] | contig_3 | contig_32 | - | - | None | None | - | - | 1.0 | O | 0 | [2] | 0 | [1] | 0 | m_49
[1] | contig_24 | contig_5 | - | - | None | None | - | - | 1.0 | O | 0 | [1] | 0 | [2] | 0 | m_50
[1] | contig_0 | contig_48 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | [2] | 1 | m_51
[2] | contig_13 | contig_26 | + | + | None | None | + | + | 1.0 | O | 0 | [2] | 0 | 0 | 0 | m_52
[1] | contig_23 | contig_5 | + | - | + | - | + | - | 1.0 | O | 0 | [1] | 0 | [2] | 1 | m_53
[2] | contig_30 | contig_58 | + | + | None | None | + | + | 1.0 | O | 0 | 0 | 0 | [1] | 0 | m_54
[1] | contig_28 | contig_29 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_55
[2] | contig_1 | contig_50 | - | - | - | - | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_56
[1] | contig_44 | contig_53 | + | + | + | + | + | + | 1.0 | O | 0 | 0 | 0 | [2] | 1 | m_57
[1] | contig_32 | contig_59 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | [2] | 1 | m_58
[2] | contig_18 | contig_4 | - | - | - | - | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_59
[3] | contig_43 | contig_46 | - | - | - | - | - | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_60
[2] | contig_32 | contig_59 | - | - | None | None | - | - | 1.0 | O | 0 | [2] | 0 | [1] | 0 | m_61
[1] | contig_39 | contig_42 | + | - | + | - | + | - | 1.0 | O | 0 | 0 | 0 | 0 | 1 | m_62
sources | ctg1 | ctg2 | oor1 | oor2 | por1 | por2 | or1 | or2 | cw | or | ssc | sc | osc | oc | map | self_id

How to interpret and work with the table

#### How to interpret column values

- sources: column represents the list of assemblies, that reported a particular assembly point. Assemblies are referred to by there ids, which in turn can be found in Assemblies summary table, as well as next to each assembly in the Individual assemblies section
- ctg1: column corresponds to first, out of two fragments, that participate in the reported assembly point.
- ctg2: column corresponds to second, out of two fragments, that participate in the reported assembly point
- or1: column corresponds to relative orientation of ctg1 wrt ctg2 in the reported assembly.
  1. + orientation corresponds to the head of ctg1 being adjacent in the reported assembly
  2. - orientation corresponds to the tail of ctg1 being adjacent in the reported assembly
- or2: column corresponds to relative orientation of ctg2 wrt ctg1 in the reported assembly.
  1. + orientation corresponds to the tail of ctg2 being adjacent in the reported assembly
  2. - orientation corresponds to the head of ctg1 being adjacent in the reported assembly
- cw: confidence weight (score) for the reported assmebly point. Equals to the sum of individual assembly points, reported by each assembly
- or: a flag determining the type os assembly point:
  1. O: oriented assembly point, that is for both fragments their extremities are specified
  2. SO: partially oriented assembly point, that is only for one out of two fragments an assembly extremity is specified
  3. U: unoriented assembly point, that is for both fragments their extremities used for assembly are not specified
- ssc: corresponds to the list of sources, with which this assembly point is Self-Semi-Conflicted. This happens, if this assembly point (at least one of its representations , if the point was reported ambiguous) in the super assembly conflicts with some other assembly point (at least one of its representations) from same sourcee. At least one of two points taken part in this conflict had to be reported ambiguous. 0 stands for non Self-Semi-Conflicted.
- sc: corresponds to the list of sources, with which this assembly point is Self-Conflicted. This happens, if this assembly point (regardless of the representations) in the super assembly, conflicts with some other assembly point (regardless of its representation) from the same source (which source is specified in the list). 0 stands for non self-Conflicted.
- osc: corresponds to the list of sources, with which this assembly point is Oout-Semi-Conflicted. This happens, if this assembly point (at least one of its representations , if the point was reported ambiguous) in the super assembly conflicts with some other assembly point (at least one of its representation) from the different source. At least one of two points taken part in this conflict had to be reported ambiguous. 0 stands for non Out-Semi-Conflicted.
- oc: corresponds to the list of sources, with which this assembly point is Out-Conflicted. This happens, if this assembly point (regardless of its representation) in the super assembly, conflicts with some other assembly point (regardless of its representation) from the different source. 0 stands for non Out-Conflicted.
- map: is a boolean flag (i.e. aither 0 or 1) corresponding whether this assmbely point participates in the reported Merged-Assembly

#### How to filter and order information in the table

- Built-in filters: every column has a filter in the table heading.
  1. If the filter is represented an input field, the value a substring of a column / row entry. Smart Datatables search is used.
  2. If the input is represented with a dropdown, then all values matching the chose value will be kept.
  3. There is a whole table filter on the top right of the table. It also accepts a string expression, but for this filter at least one value in at least one column has to at least to contain the specified string.
- Advanced filtering: There is a collapsible panel with advance filtering capabilities. Please refer to instructions in it.

Built-in and advanced filters can be combined together. The only difference is that build in filters revert filtering changes on-the-fly, once the filter criteria is removed, while for advanced filtering one has to manually revert applied filters.

using
layout

## Filter the table and draw the first graph

How to interpret and work with the graph

## Reading the graph

### Colors

scaffmatch
sga
soap2

### Edges

- Contig edge: is a directed black edge with contig name written on it. Represents the contig, participating in one or more assembly points. Direction of the edge corresponds to respective contig orientation.
  Example:

- Assembly edge: colored (based on the source) non-directed edge corresponds to the reported assembly point.
  - Non-ambiguous: all assembly edges from ambiguous assembly points are shown as dashed.
    Example:

  - Ambiguous: all assembly edges from non-ambiguous assembly points are shown as solid.
    Example:

  If the edge is shown in bold, that means that the assembly point (or a particular representation of it), that it represents participates in the produced super assembly.
  Example:

  Parallel edges correspond to assembly points, reported by respective list of sources, where such list can be determined by the color of parallel edges.
  Example:

### Modifying the graph

One can work with thr graph, using the mouse / touchpad.

- Zooming: using the scroll of the mouse, one can zoom in and out of the graph. Note that the position of the pointer determines where the zoom will be focused.
- Moving: use the standard drag operation to move the graph
- Fitting: to fit the whole drawn graph in the frame, use the Fit button at the top of the picture

### Saving graph image

Using the Save button on the top of the graph image itself, one can save the current view of the graph as a png picture.

Dr. Max A. Alekseyev: maxal@gwu.edu

The project is supported by the National Science Foundation under Grant No. IIS-1462107.

2016